@@ -75,6 +75,7 @@ sorted_classifiers = [
     "Framework :: Buildout :: Recipe",
     "Framework :: CastleCMS",
     "Framework :: CastleCMS :: Theme",
+    "Framework :: Celery",
     "Framework :: Chandler",
     "Framework :: CherryPy",
     "Framework :: CubicWeb",
@@ -94,6 +95,7 @@ sorted_classifiers = [
     "Framework :: Django :: 3.0",
     "Framework :: Django :: 3.1",
     "Framework :: Django :: 3.2",
+    "Framework :: Django :: 4.0",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
@@ -384,6 +386,7 @@ sorted_classifiers = [
     "Programming Language :: C++",
     "Programming Language :: Cold Fusion",
     "Programming Language :: Cython",
+    "Programming Language :: D",
     "Programming Language :: Delphi/Kylix",
     "Programming Language :: Dylan",
     "Programming Language :: Eiffel",
